@@ -56,13 +56,13 @@ def filter_log_events_attr(log, values, parameters=None):
     attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
     positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
-    stream = log_converter.apply(log, variant=log_converter.TO_EVENT_STREAM)
+    stream = log_converter.apply(log, variant=log_converter.TO_EVENT_STREAM, parameters={"deepcopy": False})
     if positive:
         stream = EventStream(list(filter(lambda x: x[attribute_key] in values, stream)))
     else:
         stream = EventStream(list(filter(lambda x: x[attribute_key] not in values, stream)))
 
-    filtered_log = log_converter.apply(stream)
+    filtered_log = log_converter.apply(stream, variant=log_converter.Variants.TO_EVENT_LOG)
 
     return filtered_log
 
