@@ -14,4 +14,5 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.objects.petri_net import obj, properties, semantics, utils
+
+from pm4py.objects.petri_net import obj, properties, semantics, utils, saw_net
