@@ -15,9 +15,12 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.algo.discovery.dfg.variants import native, performance
+from typing import Optional, Dict, Any, Union, Tuple, List, Set
+from pm4py.objects.log.obj import EventLog
+from pm4py.objects.conversion.log import converter as log_converter
 
 
-def apply(log, activity, parameters=None):
+def apply(log: EventLog, activity: str, parameters: Optional[Dict[Any, Any]] = None) -> Dict[str, Any]:
     """
     Gets the time passed from each preceding activity
 
@@ -39,6 +42,8 @@ def apply(log, activity, parameters=None):
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     dfg_frequency = native.native(log, parameters=parameters)
     dfg_performance = performance.performance(log, parameters=parameters)
 
