@@ -34,6 +34,7 @@ class Parameters(Enum):
     AGGREGATION_MEASURE = "aggregationMeasure"
     FONT_SIZE = "font_size"
     BGCOLOR = "bgcolor"
+    DECORATIONS = "decorations"
 
 
 def apply(net, initial_marking, final_marking, decorations=None, parameters=None):
@@ -68,6 +69,9 @@ def apply(net, initial_marking, final_marking, decorations=None, parameters=None
     font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, "12")
     bgcolor = exec_utils.get_param_value(Parameters.BGCOLOR, parameters, constants.DEFAULT_BGCOLOR)
 
+    if decorations is None:
+        decorations = exec_utils.get_param_value(Parameters.DECORATIONS, parameters, None)
+
     return graphviz_visualization(net, image_format=image_format, initial_marking=initial_marking,
                                   final_marking=final_marking, decorations=decorations, debug=debug,
                                   set_rankdir=set_rankdir, font_size=font_size, bgcolor=bgcolor)
@@ -119,20 +123,22 @@ def graphviz_visualization(net, image_format="png", initial_marking=None, final_
     # transitions
     viz.attr('node', shape='box')
     for t in net.transitions:
-        if t.label is not None:
-            if t in decorations and "label" in decorations[t] and "color" in decorations[t]:
-                viz.node(str(id(t)), decorations[t]["label"], style='filled', fillcolor=decorations[t]["color"],
-                         border='1', fontsize=font_size)
+        label = decorations[t]["label"] if t in decorations and "label" in decorations[t] else ""
+        fillcolor = decorations[t]["color"] if t in decorations and "color" in decorations[t] else None
+
+        if t.label is not None and not label:
+            label = t.label
+        if debug:
+            label = t.name
+        label = str(label)
+
+        if fillcolor is None:
+            if t.label is None:
+                fillcolor = "black"
             else:
-                viz.node(str(id(t)), str(t.label), fontsize=font_size)
-        else:
-            if debug:
-                viz.node(str(id(t)), str(t.name), fontsize=font_size)
-            elif t in decorations and "color" in decorations[t] and "label" in decorations[t]:
-                viz.node(str(id(t)), decorations[t]["label"], style='filled', fillcolor=decorations[t]["color"],
-                         fontsize=font_size)
-            else:
-                viz.node(str(id(t)), "", style='filled', fillcolor="black", fontsize=font_size)
+                fillcolor = bgcolor
+
+        viz.node(str(id(t)), label, style='filled', fillcolor=fillcolor, border='1', fontsize=font_size)
 
         if petri_properties.TRANS_GUARD in t.properties:
             guard = t.properties[petri_properties.TRANS_GUARD]
@@ -154,23 +160,27 @@ def graphviz_visualization(net, image_format="png", initial_marking=None, final_
     places_sort_list = places_sort_list_im + places_sort_list_not_im_fm + places_sort_list_fm
 
     for p in places_sort_list:
+        label = decorations[p]["label"] if p in decorations and "label" in decorations[p] else ""
+        fillcolor = decorations[p]["color"] if p in decorations and "color" in decorations[p] else bgcolor
+
+        label = str(label)
         if p in initial_marking:
             if initial_marking[p] == 1:
-                viz.node(str(id(p)), "<&#9679;>", fontsize="34", fixedsize='true', shape="circle", width='0.75')
+                viz.node(str(id(p)), "<&#9679;>", fontsize="34", fixedsize='true', shape="circle", width='0.75', style="filled", fillcolor=fillcolor)
             else:
-                viz.node(str(id(p)), str(initial_marking[p]), fontsize="34", fixedsize='true', shape="circle", width='0.75')
+                viz.node(str(id(p)), str(initial_marking[p]), fontsize="34", fixedsize='true', shape="circle", width='0.75', style="filled", fillcolor=fillcolor)
         elif p in final_marking:
             # <&#9632;>
-            viz.node(str(id(p)), "<&#9632;>", fontsize="32", shape='doublecircle', fixedsize='true', width='0.75')
+            viz.node(str(id(p)), "<&#9632;>", fontsize="32", shape='doublecircle', fixedsize='true', width='0.75', style="filled", fillcolor=fillcolor)
         else:
             if debug:
                 viz.node(str(id(p)), str(p.name), fontsize=font_size, shape="ellipse")
             else:
                 if p in decorations and "color" in decorations[p] and "label" in decorations[p]:
-                    viz.node(str(id(p)), decorations[p]["label"], style='filled', fillcolor=decorations[p]["color"],
+                    viz.node(str(id(p)), label, style='filled', fillcolor=fillcolor,
                              fontsize=font_size, shape="ellipse")
                 else:
-                    viz.node(str(id(p)), "", shape='circle', fixedsize='true', width='0.75')
+                    viz.node(str(id(p)), label, shape='circle', fixedsize='true', width='0.75', style="filled", fillcolor=fillcolor)
 
     # add arcs, in order by their source and target objects names, to avoid undeterminism in the visualization
     arcs_sort_list = sorted(list(net.arcs), key=lambda x: (x.source.name, x.target.name))
@@ -184,22 +194,25 @@ def graphviz_visualization(net, image_format="png", initial_marking=None, final_
             break
 
     for a in arcs_sort_list:
+        penwidth = decorations[a]["penwidth"] if a in decorations and "penwidth" in decorations[a] else None
+        label = decorations[a]["label"] if a in decorations and "label" in decorations[a] else ""
+        color = decorations[a]["color"] if a in decorations and "color" in decorations[a] else None
+
+        if not label and arc_weight_visible:
+            label = a.weight
+
+        label = str(label)
         arrowhead = "normal"
+
         if petri_properties.ARCTYPE in a.properties:
             if a.properties[petri_properties.ARCTYPE] == petri_properties.RESET_ARC:
                 arrowhead = "vee"
             elif a.properties[petri_properties.ARCTYPE] == petri_properties.INHIBITOR_ARC:
                 arrowhead = "dot"
-        if a in decorations and "label" in decorations[a] and "penwidth" in decorations[a]:
-            viz.edge(str(id(a.source)), str(id(a.target)), label=decorations[a]["label"],
-                     penwidth=decorations[a]["penwidth"], fontsize=font_size, arrowhead=arrowhead)
-        elif a in decorations and "color" in decorations[a]:
-            viz.edge(str(id(a.source)), str(id(a.target)), color=decorations[a]["color"], fontsize=font_size, arrowhead=arrowhead)
-        else:
-            if arc_weight_visible:
-                viz.edge(str(id(a.source)), str(id(a.target)), fontsize=font_size, arrowhead=arrowhead, label=str(a.weight))
-            else:
-                viz.edge(str(id(a.source)), str(id(a.target)), fontsize=font_size, arrowhead=arrowhead)
+
+        viz.edge(str(id(a.source)), str(id(a.target)), label=label,
+                 penwidth=penwidth, color=color, fontsize=font_size, arrowhead=arrowhead, fontcolor=color)
+
     viz.attr(overlap='false')
 
     viz.format = image_format
